summary | shortlog | log | commit | commitdiff | tree
raw | patch | inline | side by side (parent: e385847)
raw | patch | inline | side by side (parent: e385847)
author | oetiker <oetiker@a5681a0c-68f1-0310-ab6d-d61299d08faa> | |
Sat, 23 Mar 2002 09:01:43 +0000 (09:01 +0000) | ||
committer | oetiker <oetiker@a5681a0c-68f1-0310-ab6d-d61299d08faa> | |
Sat, 23 Mar 2002 09:01:43 +0000 (09:01 +0000) |
program/src/Makefile.am | patch | blob | history | |
program/src/rrd_graph.c | patch | blob | history | |
program/src/rrd_graph.h | patch | blob | history | |
program/src/rrd_tool.c | patch | blob | history |
index 18d16a030310f0d60ad321ae28df3463738aa6dd..1ed0fdccd54b86cd8647e21c9e1461d483b10f27 100644 (file)
--- a/program/src/Makefile.am
+++ b/program/src/Makefile.am
RRD_C_FILES = \
getopt.c \
getopt1.c \
- gifsize.c \
parsetime.c \
hash_32.c \
rrd_hw.c \
index 166d5624ccaa60c7e20d400a4e302825e1717bb9..2e9e0091117fb4500a96b77af3cde8003ff8e5f4 100644 (file)
--- a/program/src/rrd_graph.h
+++ b/program/src/rrd_graph.h
GF_DEF, GF_CDEF, GF_VDEF,
GF_PART};
-enum if_en {IF_GIF=0,IF_PNG=1};
+enum if_en {IF_PNG=0};
enum vdef_op_en {
VDEF_MAXIMUM /* like the MAX in (G)PRINT */
diff --git a/program/src/rrd_tool.c b/program/src/rrd_tool.c
index b1e0309d2713f2e856c7a2209c0d0d3c827eb951..72fdddb2c30c2badc45dc3848a526f6a6f070bc5 100644 (file)
--- a/program/src/rrd_tool.c
+++ b/program/src/rrd_tool.c
"\t\t[--units-exponent value]\n"
"\t\t[--step seconds]\n"
"\t\t[-f|--imginfo printfstr]\n"
- "\t\t[-a|--imgformat GIF|PNG]\n"
+ "\t\t[-a|--imgformat PNG]\n"
"\t\t[-c|--color COLORTAG#rrggbb[aa]] [-t|--title string]\n"
"\t\t[DEF:vname=rrd:ds-name:CF]\n"
"\t\t[CDEF:vname=rpn-expression]\n"
--- a/program/src/rrd_graph.c
+++ b/program/src/rrd_graph.c
enum if_en if_conv(char *string){
- conv_if(GIF,IF_GIF)
conv_if(PNG,IF_PNG)
return (-1);
if ((fd = fopen(im->graphfile,"rb")) == NULL)
return 0; /* the file does not exist */
switch (im->imgformat) {
- case IF_GIF:
- size = GifSize(fd,&(im->xgif),&(im->ygif));
- break;
case IF_PNG:
size = PngSize(fd,&(im->xgif),&(im->ygif));
break;
}
}
switch (im->imgformat) {
- case IF_GIF:
- break;
case IF_PNG:
gfx_render_png (canvas,im->xgif,im->ygif,im->zoom,0x0,fo);
break;
im->gdes_c = 0;
im->gdes = NULL;
im->zoom = 1.0;
- im->imgformat = IF_GIF; /* we default to GIF output */
+ im->imgformat = IF_PNG; /* we default to PNG output */
for(i=0;i<DIM(graph_col);i++)
im->graph_col[i]=graph_col[i];
index b86859c453e53c40974354ee8fce87860b6fdda1..9df2144359e80d9640fed11cd8d8246508bfcba4 100644 (file)